@@ -41,7 +41,7 @@ public class Adjustment extends GtkObject {
 	 * native resource.
 	 */
 	public Adjustment(int handle) {
-		this.handle = handle;
+		this.setHandle(handle);
 		initializeEventHandlers();
 	}
 
@@ -61,7 +61,7 @@ public class Adjustment extends GtkObject {
 		double stepIncrement,
 		double pageIncrement,
 		double pageSize) {
-		handle = gtk_adjustment_new(value, lower, upper, stepIncrement, pageIncrement, pageSize);
+		setHandle(gtk_adjustment_new(value, lower, upper, stepIncrement, pageIncrement, pageSize));
 		initializeEventHandlers();
 	}
 
@@ -72,7 +72,7 @@ public class Adjustment extends GtkObject {
 	 * Sets the GtkAdjustment value.
 	 */
 	public void setValue(double value) {
-		gtk_adjustment_set_value(handle, value);
+		gtk_adjustment_set_value(getHandle(), value);
 	}
 
 	/**
@@ -80,7 +80,7 @@ public class Adjustment extends GtkObject {
 	 * @return The current value of the adjustment.
 	 */
 	public double getValue() {
-		return gtk_adjustment_get_value(handle);
+		return gtk_adjustment_get_value(getHandle());
 	}
 
 	/**
@@ -91,19 +91,24 @@ public class Adjustment extends GtkObject {
 	 * emitted if the value is changed.
 	 */
 	public void clampPage(double lower, double upper) {
-		gtk_adjustment_clamp_page(handle, lower, upper);
+		gtk_adjustment_clamp_page(getHandle(), lower, upper);
 	}
 
 	/* **************************************
 	 * Event Handling
 	 ****************************************/
 
+	/** Are events initialized? */
+	private boolean eventsInitialized = false;
 	/**
 	 * Initialize this widget to receive its' own events so it can
 	 * propogate them to the listeners.
 	 */
 	protected void initializeEventHandlers() {
-		evtMap.initialize(this);
+		if (!eventsInitialized) {
+			evtMap.initialize(this);
+			eventsInitialized = true;
+		}
 	}
 
 	public Class getEventListenerClass(String signal) {
