@@ -33,8 +33,8 @@ public class Button extends Bin {
 	}
 
 	protected void noopInit() {
-		if (-1 == handle) {
-			handle = gtk_button_new();
+		if (-1 == getHandle()) {
+			setHandle(gtk_button_new());
 			initializeEventHandlers();
 		}
 	}
@@ -52,9 +52,9 @@ public class Button extends Bin {
 	 */
 	public Button(String label, boolean hasMnemonic) {
 		if (hasMnemonic) {
-			handle = gtk_button_new_with_mnemonic(label);
+			setHandle(gtk_button_new_with_mnemonic(label));
 		} else {
-			handle = gtk_button_new_with_label(label);
+			setHandle(gtk_button_new_with_label(label));
 		}
 		initializeEventHandlers();
 	}
@@ -70,7 +70,7 @@ public class Button extends Bin {
 	 * @see StockItem
 	 */
 	public Button(GtkStockItem stockItem) {
-		handle = gtk_button_new_from_stock(stockItem.getString());
+		setHandle(gtk_button_new_from_stock(stockItem.getString()));
 		initializeEventHandlers();
 	}
 
@@ -85,7 +85,7 @@ public class Button extends Bin {
 	 * @see StockItem
 	 */
 	public Button(String StockItem) {
-		handle = gtk_button_new_from_stock(StockItem);
+		setHandle(gtk_button_new_from_stock(StockItem));
 		initializeEventHandlers();
 	}
 
@@ -93,7 +93,8 @@ public class Button extends Bin {
 	 * Construct a button using a handle to a native resource.
 	 */
 	public Button(int handle) {
-		super(handle);
+		setHandle(handle);
+		initializeEventHandlers();
 	}
 
 	/**
@@ -101,7 +102,7 @@ public class Button extends Bin {
 	 * up for this event then they will be called
 	 */
 	public void press() {
-		gtk_button_pressed(handle);
+		gtk_button_pressed(getHandle());
 	}
 
 	/**
@@ -109,7 +110,7 @@ public class Button extends Bin {
 	 * up for this event, they will be called.
 	 */
 	public void release() {
-		gtk_button_released(handle);
+		gtk_button_released(getHandle());
 	}
 
 	/**
@@ -117,7 +118,7 @@ public class Button extends Bin {
 	 * for this event, they will be called
 	 */
 	public void click() {
-		gtk_button_clicked(handle);
+		gtk_button_clicked(getHandle());
 	}
 
 	/**
@@ -125,7 +126,7 @@ public class Button extends Bin {
 	 * for this event, they will be called.
 	 */
 	public void enter() {
-		gtk_button_enter(handle);
+		gtk_button_enter(getHandle());
 	}
 
 	/**
@@ -133,21 +134,21 @@ public class Button extends Bin {
 	 * for this event, they will be called.
 	 */
 	public void leave() {
-		gtk_button_leave(handle);
+		gtk_button_leave(getHandle());
 	}
 
 	/**
 	 * Sets the relief style of the edges of the Button widget. 
 	 */
 	public void setRelief(ReliefStyle newRelief) {
-		gtk_button_set_relief(handle, newRelief.getValue());
+		gtk_button_set_relief(getHandle(), newRelief.getValue());
 	}
 
 	/**
 	 * Returns the current relief style of the button
 	 */
 	public ReliefStyle getRelief() {
-		return ReliefStyle.intern(gtk_button_get_relief(handle));
+		return ReliefStyle.intern(gtk_button_get_relief(getHandle()));
 	}
 
 	/**
@@ -156,14 +157,14 @@ public class Button extends Bin {
 	 * buttons, then newLabel should be the name of the stock item to be used.
 	 */
 	public void setLabel(String newLabel) {
-		gtk_button_set_label(handle, newLabel);
+		gtk_button_set_label(getHandle(), newLabel);
 	}
 
 	/**
 	 * Returns the label which is being used on the button.
 	 */
 	public String getLabel() {
-		return gtk_button_get_label(handle);
+		return gtk_button_get_label(getHandle());
 	}
 
 	/**
@@ -171,7 +172,7 @@ public class Button extends Bin {
 	 * character should be used for the mnemonic accelerator key.
 	 */
 	public void setUseUnderline(boolean useUnderLine) {
-		gtk_button_set_use_underline(handle, useUnderLine);
+		gtk_button_set_use_underline(getHandle(), useUnderLine);
 	}
 
 	/**
@@ -179,7 +180,7 @@ public class Button extends Bin {
 	 * mnemonic.
 	 */
 	public boolean getUseUnderline() {
-		return gtk_button_get_use_underline(handle);
+		return gtk_button_get_use_underline(getHandle());
 	}
 
 	// TODO: give a doc link to list of stock items. an example application,
@@ -194,22 +195,22 @@ public class Button extends Bin {
 	 * @param useStock true if this button should use stock items
 	 */
 	public void setUseStock(boolean useStock) {
-		gtk_button_set_use_stock(handle, useStock);
+		gtk_button_set_use_stock(getHandle(), useStock);
 	}
 
 	/**
 	 * Returns true if this button is using stock items
 	 */
 	public boolean getUseStock() {
-		return gtk_button_get_use_stock(handle);
+		return gtk_button_get_use_stock(getHandle());
 	}
 	
 	public void setFocusOnClick(boolean focusOnClick) {
-		gtk_button_set_focus_on_click(handle, focusOnClick);
+		gtk_button_set_focus_on_click(getHandle(), focusOnClick);
 	}
 	
 	public boolean getFocusOnClick() {
-		return gtk_button_get_focus_on_click(handle);
+		return gtk_button_get_focus_on_click(getHandle());
 	}
 
 	/* **************************************
@@ -286,9 +287,15 @@ public class Button extends Bin {
 		fireButtonEvent(new ButtonEvent(this, ButtonEvent.Type.RELEASE));
 	}
 
+	/** Are events initialized? */
+	private boolean eventsInitialized = false;
+
 	protected void initializeEventHandlers() {
-		super.initializeEventHandlers();
-		evtMap.initialize(this);
+		if (!eventsInitialized) {
+			super.initializeEventHandlers();
+			evtMap.initialize(this);
+			eventsInitialized = true;
+		}
 	}
 
 	public Class getEventListenerClass(String signal) {
