@@ -1,12 +1,7 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2002 the Java-Gnome Team, all rights reserved.
- *
- * The Java-Gnome Team Members:
- *   Jean Van Wyk <jeanvanwyk@iname.com>
- *   Jeffrey S. Morgan <jeffrey.morgan@bristolwest.com>
- *   Dan Bornstein <danfuzz@milk.com>
+ * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome bindings library is free software distributed under
  * the terms of the GNU Library General Public License version 2.
@@ -39,12 +34,13 @@ public class Calendar extends Widget {
 	 * Construct a calendar using a handle to a native resource.
 	 */
 	public Calendar(int handle) {
-		super(handle);
+		setHandle(handle);
+		initializeEventHandlers();
 	}
 
 	protected void noopInit() {
-		if (-1 == handle) {
-			handle = gtk_calendar_new();
+		if (-1 == getHandle()) {
+			setHandle(gtk_calendar_new());
 			initializeEventHandlers();
 		}
 	}
@@ -56,7 +52,7 @@ public class Calendar extends Widget {
 	 * @param year The year the month is in.
 	 */
 	public void selectMonth(int month, int year) {
-		Calendar.gtk_calendar_select_month(handle, month, year);
+		Calendar.gtk_calendar_select_month(getHandle(), month, year);
 	}
 
 	/**
@@ -66,7 +62,7 @@ public class Calendar extends Widget {
 	 * currently selected day.
 	 */
 	public void selectDay(int day) {
-		Calendar.gtk_calendar_select_day(handle, day);
+		Calendar.gtk_calendar_select_day(getHandle(), day);
 	}
 
 	/**
@@ -75,7 +71,7 @@ public class Calendar extends Widget {
 	 * @param day The day number to mark between 1 and 31.
 	 */
 	public void markDay(int day) {
-		Calendar.gtk_calendar_mark_day(handle, day);
+		Calendar.gtk_calendar_mark_day(getHandle(), day);
 	}
 
 	/**
@@ -84,14 +80,14 @@ public class Calendar extends Widget {
 	 * @param day The day number to unmark between 1 and 31.
 	 */
 	public void unmarkDay(int day) {
-		Calendar.gtk_calendar_unmark_day(handle, day);
+		Calendar.gtk_calendar_unmark_day(getHandle(), day);
 	}
 
 	/**
 	 * Remove all visual marks.
 	 */
 	public void clearMarks() {
-		Calendar.gtk_calendar_clear_marks(handle);
+		Calendar.gtk_calendar_clear_marks(getHandle());
 	}
 
 	/**
@@ -101,7 +97,7 @@ public class Calendar extends Widget {
 	 * @param displayOptions The options to set.
 	 */
 	public void setDisplayOptions(CalendarDisplayOptions displayOptions) {
-		gtk_calendar_set_display_options(handle, displayOptions.getValue());
+		gtk_calendar_set_display_options(getHandle(), displayOptions.getValue());
 	}
 	
 	/**
@@ -109,7 +105,7 @@ public class Calendar extends Widget {
 	 * month headings.
 	 */
 	 public CalendarDisplayOptions getDisplayOptions() {
-		return CalendarDisplayOptions.intern(gtk_calendar_get_display_options(handle));
+		return CalendarDisplayOptions.intern(gtk_calendar_get_display_options(getHandle()));
 	}
 
 	/**
@@ -122,7 +118,7 @@ public class Calendar extends Widget {
 		int[] year = new int[1];
 		int[] month = new int[1];
 		int[] day = new int[1];
-		Calendar.gtk_calendar_get_date(handle, year, month, day);
+		Calendar.gtk_calendar_get_date(getHandle(), year, month, day);
 		java.util.Calendar cal = java.util.Calendar.getInstance();
 		cal.set(java.util.Calendar.YEAR, year[0]);
 		cal.set(java.util.Calendar.MONTH, month[0]);
@@ -135,7 +131,7 @@ public class Calendar extends Widget {
 	 * with the <code>thaw()</code> method.
 	 */
 	public void freeze() {
-		Calendar.gtk_calendar_freeze(handle);
+		Calendar.gtk_calendar_freeze(getHandle());
 	}
 
 	/**
@@ -143,7 +139,7 @@ public class Calendar extends Widget {
 	 * <code>freeze()</code> are displayed.
 	 */
 	public void thaw() {
-		Calendar.gtk_calendar_thaw(handle);
+		Calendar.gtk_calendar_thaw(getHandle());
 	}
 
 	/* **************************************
@@ -212,9 +208,15 @@ public class Calendar extends Widget {
 		fireCalendarEvent(new CalendarEvent(this, CalendarEvent.Type.YEAR_CHANGED));
 	}
 
+	/** Are events initialized? */
+	private boolean eventsInitialized = false;
+
 	protected void initializeEventHandlers() {
-		super.initializeEventHandlers();
-		evtMap.initialize(this);
+		if (!eventsInitialized) {
+			super.initializeEventHandlers();
+			evtMap.initialize(this);
+			eventsInitialized = true;
+		}
 	}
 
 	public Class getEventListenerClass(String signal) {
