@@ -11,6 +11,7 @@ package org.gnu.gtk;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.ExpanderEvent;
 import org.gnu.gtk.event.ExpanderListener;
@@ -38,10 +39,11 @@ public class Expander extends Bin {
 	 */
 	public Expander(String label, boolean hasMnemonic) {
 		if (hasMnemonic) {
-			handle = gtk_expander_new_with_mnemonic(label);
+			setHandle(gtk_expander_new_with_mnemonic(label));
 		} else {
-			handle = gtk_expander_new(label);
-		}		
+			setHandle(gtk_expander_new(label));
+		}
+		initializeEventHandlers();
 	}
 	
 	/**
@@ -51,7 +53,7 @@ public class Expander extends Bin {
 	 * @param expanded whether the child widget is revealed
 	 */
 	public void setExpanded(boolean expanded) {
-		gtk_expander_set_expanded(handle, expanded);
+		gtk_expander_set_expanded(getHandle(), expanded);
 	}
 	
 	/**
@@ -61,7 +63,7 @@ public class Expander extends Bin {
 	 * @return the current state of the expander
 	 */
 	public boolean getExpanded() {
-		return gtk_expander_get_expanded(handle);
+		return gtk_expander_get_expanded(getHandle());
 	}
 	
 	/**
@@ -70,7 +72,7 @@ public class Expander extends Bin {
 	 * @param spacing  distance between the Expander and child in pixels
 	 */
 	public void setSpacing(int spacing) {
-		gtk_expander_set_spacing(handle, spacing);
+		gtk_expander_set_spacing(getHandle(), spacing);
 	}
 	
 	/**
@@ -78,7 +80,7 @@ public class Expander extends Bin {
 	 * @return spacing between the expander and child in pixels
 	 */
 	public int getSpacing() {
-		return gtk_expander_get_spacing(handle);
+		return gtk_expander_get_spacing(getHandle());
 	}
 	
 	/**
@@ -87,7 +89,7 @@ public class Expander extends Bin {
 	 * @param label a string
 	 */
 	public void setLabel(String label) {
-		gtk_expander_set_label(handle, label);
+		gtk_expander_set_label(getHandle(), label);
 	}
 	
 	/**
@@ -98,7 +100,7 @@ public class Expander extends Bin {
 	 * @return  the text of the label widget
 	 */
 	public String getLabel() {
-		return gtk_expander_get_label(handle);
+		return gtk_expander_get_label(getHandle());
 	}
 	
 	/**
@@ -107,7 +109,7 @@ public class Expander extends Bin {
 	 * @param useUnderline TRUE if underlines in the text indicate mnemonics
 	 */
 	public void setUseUnderline(boolean useUnderline) {
-		gtk_expander_set_use_underline(handle, useUnderline);
+		gtk_expander_set_use_underline(getHandle(), useUnderline);
 	}
 	
 	/**
@@ -116,7 +118,7 @@ public class Expander extends Bin {
 	 * @return <code>TRUE</code> if an embedded underline in the Expander label indicates the mnemonic accelerator keys. 
 	 */
 	public boolean getUseUnderline() {
-		return gtk_expander_get_use_underline(handle);
+		return gtk_expander_get_use_underline(getHandle());
 	}
 	
 	/**
@@ -126,7 +128,7 @@ public class Expander extends Bin {
 	 * @param useMarkup <code>TRUE</code> if the label's text should be parsed for markup
 	 */
 	public void setUseMarkup(boolean useMarkup) {
-		gtk_expander_set_use_markup(handle, useMarkup);
+		gtk_expander_set_use_markup(getHandle(), useMarkup);
 	}
 	
 	/**
@@ -136,7 +138,7 @@ public class Expander extends Bin {
 	 * @return <code>TRUE</code> if the label's text will be parsed for markup
 	 */
 	public boolean getUseMarkup() {
-		return gtk_expander_get_use_markup(handle);
+		return gtk_expander_get_use_markup(getHandle());
 	}
 	
 	/**
@@ -145,7 +147,7 @@ public class Expander extends Bin {
 	 * @param label the new label widget
 	 */
 	public void setLabelWidget(Widget label) {
-		gtk_expander_set_label_widget(handle, label.getHandle());
+		gtk_expander_set_label_widget(getHandle(), label.getHandle());
 	}
 	
 	/**
@@ -154,7 +156,13 @@ public class Expander extends Bin {
 	 * @return the label widget, or <code>NULL</code> if there is none 
 	 */
 	public Widget getLabelWidget() {
-		return new Widget(gtk_expander_get_label_widget(handle));
+		int hndl = gtk_expander_get_label_widget(getHandle());
+		if (0 == hndl)
+			return null;
+		GObject obj = retrieveGObject(hndl);
+		if (null != obj)
+			return (Widget)obj;
+		return new Widget(hndl);
 	}
 	
 	/**
@@ -218,9 +226,15 @@ public class Expander extends Bin {
 		fireExpanderEvent(new ExpanderEvent(this, ExpanderEvent.Type.ACTIVATE));
 	}
 
+	/** Are events initialized? */
+	private boolean eventsInitialized = false;
+
 	protected void initializeEventHandlers() {
-		super.initializeEventHandlers();
-		evtMap.initialize(this);
+		if (!eventsInitialized) {
+			super.initializeEventHandlers();
+			evtMap.initialize(this);
+			eventsInitialized = true;
+		}
 	}
 
 	public Class getEventListenerClass(String signal) {
@@ -250,7 +264,7 @@ public class Expander extends Bin {
 	native static final protected int gtk_expander_get_type ();
 	native static final protected int gtk_expander_new(String label);
 	native static final protected int gtk_expander_new_with_mnemonic(String label);
-	native static final protected int gtk_expander_set_expanded(int expander, boolean expanded);
+	native static final protected void gtk_expander_set_expanded(int expander, boolean expanded);
 	native static final protected boolean gtk_expander_get_expanded(int expander);
 	native static final protected void gtk_expander_set_spacing(int expander, int spacing);
 	native static final protected int gtk_expander_get_spacing(int expander);
