@@ -28,24 +28,24 @@ public interface FileChooser {
 	 */
 	void setCurrentName(String name);
 	String getFilename();
-	void setFilename(String filename);
-	void selectFilename(String filename);
+	boolean setFilename(String filename);
+	boolean selectFilename(String filename);
 	void unselectFilename(String filename);
 	void selectAll();
 	void unselectAll();
 	String[] getFilenames();
-	void setCurrentFolder(String folder);
+	boolean setCurrentFolder(String folder);
 	String getCurrentFolder();
 	
 	/*
 	 * URI manipulation
 	 */
 	String getURI();
-	void setURI(String uri);
-	void selectURI(String uri);
+	boolean setURI(String uri);
+	boolean selectURI(String uri);
 	void unselectURI(String uri);
 	String[] getURIs();
-	void setCurrentFolderURI(String folder);
+	boolean setCurrentFolderURI(String folder);
 	String getCurrentFolderURI();
 	
 	/*
