@@ -22,7 +22,7 @@ public class IMContext extends GObject
 	 * Sets the client window for the input context.
 	 */
 	public void setClientWindow(org.gnu.gdk.Window window) {
-		gtk_im_context_set_client_window(handle, window.getHandle());
+		gtk_im_context_set_client_window(getHandle(), window.getHandle());
 	}
 	
 	/**
@@ -33,23 +33,23 @@ public class IMContext extends GObject
 	}
 	
 	public void focusIn() {
-		gtk_im_context_focus_in(handle);
+		gtk_im_context_focus_in(getHandle());
 	}
 	
 	public void focusOut() {
-		gtk_im_context_focus_out(handle);
+		gtk_im_context_focus_out(getHandle());
 	}
 	
 	public void reset() {
-		gtk_im_context_reset(handle);
+		gtk_im_context_reset(getHandle());
 	}
 	
 	public void setCursorLocation(Rectangle rect) {
-		gtk_im_context_set_cursor_location(handle, rect.getHandle());
+		gtk_im_context_set_cursor_location(getHandle(), rect.getHandle());
 	}
 	
 	public void setUsePreedit(boolean usePreedit) {
-		gtk_im_context_set_use_preedit(handle, usePreedit);
+		gtk_im_context_set_use_preedit(getHandle(), usePreedit);
 	}
 
     /****************************************
