@@ -9,6 +9,7 @@
 
 package org.gnu.gtk;
 
+import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 
 /**
@@ -26,10 +27,10 @@ public class Paned extends Container {
 	 * Construct a new Paned from a handle to a native resource.
 	 */
 	protected Paned(int handle) {
-	    super(handle);
+		setHandle(handle);
 	}
 
-        Paned() {}
+	Paned() {}
 	
 	protected void noopInit() {}
 	
@@ -39,7 +40,7 @@ public class Paned extends Container {
 	 * @param child The child Widget to add.
 	 */
 	public void add1(Widget child) {
-		Paned.gtk_paned_add1(handle, child.getHandle());
+		Paned.gtk_paned_add1(getHandle(), child.getHandle());
 	}
 	
 	/**
@@ -48,7 +49,7 @@ public class Paned extends Container {
 	 * @param child The child Widget to add.
 	 */
 	public void add2(Widget child) {
-		Paned.gtk_paned_add2(handle, child.getHandle());
+		Paned.gtk_paned_add2(getHandle(), child.getHandle());
 	}
 	
 	/**
@@ -59,7 +60,7 @@ public class Paned extends Container {
 	 * @param shrink can this child be made smaller than its request.
 	 */
 	public void pack1(Widget child, boolean resize, boolean shrink) {
-		Paned.gtk_paned_pack1(handle, child.getHandle(), resize, shrink);
+		Paned.gtk_paned_pack1(getHandle(), child.getHandle(), resize, shrink);
 	}
 	
 	/**
@@ -70,7 +71,7 @@ public class Paned extends Container {
 	 * @param shrink can this child be made smaller than its request.
 	 */
 	public void pack2(Widget child, boolean resize, boolean shrink) {
-		Paned.gtk_paned_pack2(handle, child.getHandle(), resize, shrink);
+		Paned.gtk_paned_pack2(getHandle(), child.getHandle(), resize, shrink);
 	}
 	
 	/**
@@ -80,7 +81,7 @@ public class Paned extends Container {
 	 * means that the position is unset.
 	 */
 	public void setPosition(int position) {
-		Paned.gtk_paned_set_position(handle, position);
+		Paned.gtk_paned_set_position(getHandle(), position);
 	}
 	
 	/**
@@ -89,15 +90,27 @@ public class Paned extends Container {
 	 * @return The position of the divider between the two panes.
 	 */
 	public int getPosition() {
-		return Paned.gtk_paned_get_position(handle);
+		return Paned.gtk_paned_get_position(getHandle());
 	}
 	
 	public Widget getChild1() {
-		return new Widget(gtk_paned_get_child1(handle));
+		int hndl = gtk_paned_get_child1(getHandle());
+		if (0 == hndl)
+			return null;
+		GObject obj = retrieveGObject(hndl);
+		if (null != obj)
+			return (Widget)obj;
+		return new Widget(hndl);
 	}
 	
 	public Widget getChild2() {
-		return new Widget(gtk_paned_get_child2(handle));
+		int hndl = gtk_paned_get_child2(getHandle());
+		if (0 == hndl)
+			return null;
+		GObject obj = retrieveGObject(hndl);
+		if (null != obj)
+			return (Widget)obj;
+		return new Widget(hndl);
 	}
 	
 	/**
