@@ -11,24 +11,31 @@ package org.gnu.gtk;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.gnu.glib.GObject;
+
 /**
  */
 public class RadioAction extends ToggleAction {
 	
 	public RadioAction(String name, String label, String tooltip, String stockId, int value) {
-		handle = gtk_radio_action_new(name, label, tooltip, stockId, value);
+		setHandle(gtk_radio_action_new(name, label, tooltip, stockId, value));
 	}
 	
 	RadioAction(int handle) {
-		super(handle);
+		setHandle(handle);
 	}
 
 
 	public List getGroup(){
-		int[] group = gtk_radio_action_get_group(handle);
+		int[] group = gtk_radio_action_get_group(getHandle());
 		List ret = new ArrayList();
 		for (int i = 0; i < group.length; i++) {
-			RadioAction action = new RadioAction(group[i]);
+			GObject obj = retrieveGObject(group[i]);
+			RadioAction action;
+			if (null != obj)
+				action = (RadioAction)obj;
+			else
+				action = new RadioAction(group[i]);
 			ret.add(action);
 		}
 		return ret;
@@ -41,11 +48,11 @@ public class RadioAction extends ToggleAction {
 		for (int i = 0; i < group.size(); i++) {
 			values[i] = ((RadioAction)group.get(i)).getHandle();
 		}
-		gtk_radio_action_set_group(handle, values);
+		gtk_radio_action_set_group(getHandle(), values);
 	}
 	
 	public int getCurrentValue() {
-		return gtk_radio_action_get_current_value(handle);
+		return gtk_radio_action_get_current_value(getHandle());
 	}
 	
 
