@@ -9,6 +9,7 @@
 
 package org.gnu.gtk;
 
+import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 
 /**
@@ -19,7 +20,7 @@ import org.gnu.glib.Type;
 public class RadioMenuItem extends CheckMenuItem {
 
 	public RadioMenuItem(RadioMenuItem[] group) {
-		if (-1 == handle) {
+		if (-1 == getHandle()) {
 			int[] groupHandle;
 			if (null != group) {
 				groupHandle = new int[group.length];
@@ -28,7 +29,7 @@ public class RadioMenuItem extends CheckMenuItem {
 				}
 			} else
 				groupHandle = null;
-			handle = gtk_radio_menu_item_new(groupHandle);
+			setHandle(gtk_radio_menu_item_new(groupHandle));
 		}
 		initializeEventHandlers();
 	}
@@ -55,9 +56,9 @@ public class RadioMenuItem extends CheckMenuItem {
 		} else
 			groupHandle = null;
 		if (hasMnemonic) {
-			handle = gtk_radio_menu_item_new_with_mnemonic(groupHandle, label);
+			setHandle(gtk_radio_menu_item_new_with_mnemonic(groupHandle, label));
 		} else {
-			handle = gtk_radio_menu_item_new_with_label(groupHandle, label);
+			setHandle(gtk_radio_menu_item_new_with_label(groupHandle, label));
 		}
 		initializeEventHandlers();
 	}
@@ -68,7 +69,7 @@ public class RadioMenuItem extends CheckMenuItem {
 			hndl = 0;
 		else
 			hndl = group.getHandle();
-		handle = gtk_radio_menu_item_new_from_widget(hndl);
+		setHandle(gtk_radio_menu_item_new_from_widget(hndl));
 		initializeEventHandlers();
 	}
 	
@@ -79,9 +80,9 @@ public class RadioMenuItem extends CheckMenuItem {
 		else
 			hndl = group.getHandle();
 		if (hasMnemonic) {
-			handle = gtk_radio_menu_item_new_with_mnemonic_from_widget(hndl, label);
+			setHandle(gtk_radio_menu_item_new_with_mnemonic_from_widget(hndl, label));
 		} else {
-			handle = gtk_radio_menu_item_new_with_label_from_widget(hndl, label);
+			setHandle(gtk_radio_menu_item_new_with_label_from_widget(hndl, label));
 		}
 		initializeEventHandlers();
 	}
@@ -90,16 +91,21 @@ public class RadioMenuItem extends CheckMenuItem {
 	 * Construct a RadioMenuItem using a handle to a native resource.
 	 */
 	RadioMenuItem(int handle) {
-	    super(handle);
+	    setHandle(handle);
+	    initializeEventHandlers();
 	}
 
 	protected void noopInit() {}
 
 	public RadioMenuItem[] getGroup() {
-		int[] hndls = gtk_radio_menu_item_get_group(handle);
+		int[] hndls = gtk_radio_menu_item_get_group(getHandle());
 		RadioMenuItem[] items = new RadioMenuItem[hndls.length];
 		for (int i = 0; i < hndls.length; i++) {
-			items[i] = new RadioMenuItem(hndls[i]);
+			GObject obj = retrieveGObject(hndls[i]);
+			if (null != obj)
+				items[i] = (RadioMenuItem)obj;
+			else
+				items[i] = new RadioMenuItem(hndls[i]);
 		}
 		return items;
 	}
@@ -109,7 +115,7 @@ public class RadioMenuItem extends CheckMenuItem {
 		for (int i = 0; i < group.length; i++) {
 			hndls[i] = group[i].getHandle();
 		}
-		gtk_radio_menu_item_set_group(handle, hndls);
+		gtk_radio_menu_item_set_group(getHandle(), hndls);
 	}
 	
 	/**
