@@ -12,6 +12,7 @@ package org.gnu.gtk;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.GtkEventType;
 import org.gnu.gtk.event.TreeViewEvent;
@@ -111,8 +112,8 @@ public class TreeView extends Container {
 	 * Create a new TreeView object.
 	 */
 	public TreeView() {
-		if (-1 == handle) {
-			handle = gtk_tree_view_new();
+		if (-1 == getHandle()) {
+			setHandle(gtk_tree_view_new());
 			initializeEventHandlers();
 		}
 	}
@@ -120,15 +121,16 @@ public class TreeView extends Container {
 	/**
 	 * Creates a new tree view from a native handle
 	 */
-	protected TreeView(int handle) {
-	    super(handle);
+	public TreeView(int handle) {
+		setHandle(handle);
+		initializeEventHandlers();
 	}
 
 	/**
 	 * Creates a new TreeView Widget with the initial model set
 	 */
 	public TreeView(TreeModel model) {
-		handle = gtk_tree_view_new_with_model(model.getHandle());
+		setHandle(gtk_tree_view_new_with_model(model.getHandle()));
 		initializeEventHandlers();
 	}
 
@@ -139,7 +141,11 @@ public class TreeView extends Container {
 	 * Returns the model associated with this tree.
 	 */
 	public TreeModel getModel() {
-		return new TreeModel(gtk_tree_view_get_model(handle));
+		int hndl = gtk_tree_view_get_model(getHandle());
+		GObject obj = retrieveGObject(hndl);
+		if (null != obj)
+			return (TreeModel)obj;
+		return new TreeModel(hndl);
 	}
 
 	/**
@@ -149,7 +155,7 @@ public class TreeView extends Container {
 	 * @return The number of columns in tree_view after appending.
 	 */
 	public int appendColumn(TreeViewColumn column) {
-		return gtk_tree_view_append_column(handle, column.getHandle());
+		return gtk_tree_view_append_column(getHandle(), column.getHandle());
 	}
 
 	/**
@@ -160,7 +166,7 @@ public class TreeView extends Container {
 	 * @return The number of columns in tree_view after insertion.
 	 */
 	public int insertColumn(TreeViewColumn column, int position) {
-		return gtk_tree_view_insert_column(handle, column.getHandle(), position);
+		return gtk_tree_view_insert_column(getHandle(), column.getHandle(), position);
 	}
 
 	/**
@@ -169,14 +175,18 @@ public class TreeView extends Container {
 	 * @return The number of columns in tree_view after removing.
 	 */
 	public int removeColumn(TreeViewColumn column) {
-		return gtk_tree_view_remove_column(handle, column.getHandle());
+		return gtk_tree_view_remove_column(getHandle(), column.getHandle());
 	}
 
 	/**
 	 * Gets the TreeSelection associated with this widget
 	 */
 	public TreeSelection getSelection() {
-		return new TreeSelection(gtk_tree_view_get_selection(handle));
+		int hndl = gtk_tree_view_get_selection(getHandle());
+		GObject obj = retrieveGObject(hndl);
+		if (null != obj)
+			return (TreeSelection)obj;
+		return new TreeSelection(hndl);
 	}
 
 	/**
@@ -184,28 +194,32 @@ public class TreeView extends Container {
 	 * @return A GtkAdjustment object, or NULL if none is currently being used.
 	 */
 	public Adjustment getHAdjustment() {
-		return new Adjustment(gtk_tree_view_get_hadjustment(handle));
+		int hndl = gtk_tree_view_get_hadjustment(getHandle());
+		GObject obj = retrieveGObject(hndl);
+		if (null != obj)
+			return (Adjustment)obj;
+		return new Adjustment(hndl);
 	}
 
 	/**
 	 * Sets the Adjustment for the current horizontal aspect.
 	 */
 	public void setHAdjustment(Adjustment hadj) {
-		gtk_tree_view_set_hadjustment(handle, hadj.getHandle());
+		gtk_tree_view_set_hadjustment(getHandle(), hadj.getHandle());
 	}
 
 	/**
 	 * Gets the Adjustment currently being used for the vertical aspect.
 	 */
 	public Adjustment getVAdjustment() {
-		return new Adjustment(gtk_tree_view_get_vadjustment(handle));
+		return new Adjustment(gtk_tree_view_get_vadjustment(getHandle()));
 	}
 
 	/**
 	 * Sets the Adjustment for the current vertical aspect.
 	 */
 	public void setVAdjustment(Adjustment vadj) {
-		gtk_tree_view_set_vadjustment(handle, vadj.getHandle());
+		gtk_tree_view_set_vadjustment(getHandle(), vadj.getHandle());
 	}
 
 	/**
@@ -213,7 +227,7 @@ public class TreeView extends Container {
 	 * @param headersVisible TRUE if the headers are visibl
 	 */
 	public void setHeadersVisible(boolean headersVisible) {
-		gtk_tree_view_set_headers_visible(handle, headersVisible);
+		gtk_tree_view_set_headers_visible(getHandle(), headersVisible);
 	}
 	
 	/**
@@ -221,7 +235,7 @@ public class TreeView extends Container {
 	 * @return
 	 */
 	public boolean getHeadersVisible() {
-		return gtk_tree_view_get_headers_visible(handle);
+		return gtk_tree_view_get_headers_visible(getHandle());
 	}
 
 	/**
@@ -229,7 +243,7 @@ public class TreeView extends Container {
 	 * @param setting TRUE if the columns are clickable.
 	 */
 	public void setHeadersClickable(boolean setting) {
-		gtk_tree_view_set_headers_clickable(handle, setting);
+		gtk_tree_view_set_headers_clickable(getHandle(), setting);
 	}
 
 	/**
@@ -247,11 +261,11 @@ public class TreeView extends Container {
 	 * @param setting TRUE if the tree requires reading across rows
 	 */
 	public void setAlternateRowColor(boolean setting) {
-		gtk_tree_view_set_rules_hint(handle, setting);
+		gtk_tree_view_set_rules_hint(getHandle(), setting);
 	}
 	
 	public boolean getAlternateRowColor() {
-		return gtk_tree_view_get_rules_hint(handle);
+		return gtk_tree_view_get_rules_hint(getHandle());
 	}
 
 	/**
@@ -261,12 +275,13 @@ public class TreeView extends Container {
 	 * of columns.
 	 */
 	public TreeViewColumn getColumn(int position) {
-		int h = gtk_tree_view_get_column(handle, position);
-		if (h < 0){
+		int h = gtk_tree_view_get_column(getHandle(), position);
+		if (h < 0)
 			return null;
-		}else{
-			return new TreeViewColumn(h);
-		}
+		GObject obj = retrieveGObject(h);
+		if (null != obj)
+			return (TreeViewColumn)obj;
+		return new TreeViewColumn(h);
 	}
 
 	/**
@@ -277,7 +292,7 @@ public class TreeView extends Container {
 	 * NULL.
 	 */
 	public void moveColumn(TreeViewColumn column, TreeViewColumn baseColumn) {
-		gtk_tree_view_move_column_after(handle, column.getHandle(), baseColumn.getHandle());
+		gtk_tree_view_move_column_after(getHandle(), column.getHandle(), baseColumn.getHandle());
 	}
 
 	/**
@@ -287,11 +302,17 @@ public class TreeView extends Container {
 	 * @param column NULL, or the column to draw the expander arrow at.
 	 */
 	public void setExpanderColumn(TreeViewColumn column) {
-		gtk_tree_view_set_expander_column(handle, column.getHandle());
+		gtk_tree_view_set_expander_column(getHandle(), column.getHandle());
 	}
 	
 	public TreeViewColumn getExpanderColumn() {
-		return new TreeViewColumn(gtk_tree_view_get_expander_column(handle));
+		int hndl = gtk_tree_view_get_expander_column(getHandle());
+		if (hndl < 0)
+			return null;
+		GObject obj = retrieveGObject(hndl);
+		if (null != obj)
+			return (TreeViewColumn)obj;
+		return new TreeViewColumn(hndl);
 	}
 
 	/**
@@ -313,7 +334,7 @@ public class TreeView extends Container {
 	 * column.
 	 */
 	public void scrollToCell(TreePath path, TreeViewColumn column, double rowAlign, double colAlign) {
-		gtk_tree_view_scroll_to_cell(handle, path.getHandle(), column.getHandle(), true, rowAlign, colAlign);
+		gtk_tree_view_scroll_to_cell(getHandle(), path.getHandle(), column.getHandle(), true, rowAlign, colAlign);
 	}
 	
 	/**
@@ -324,7 +345,7 @@ public class TreeView extends Container {
 	 * @param y
 	 */
 	public void scrollToPoint(int x, int y) {
-		gtk_tree_view_scroll_to_point(handle, x, y);
+		gtk_tree_view_scroll_to_point(getHandle(), x, y);
 	}
 
 	/**
@@ -334,7 +355,7 @@ public class TreeView extends Container {
 	 * @param column The TreeViewColumn to move horizontally to
 	 */
 	public void scrollToCell(TreePath path, TreeViewColumn column) {
-		gtk_tree_view_scroll_to_cell(handle, path.getHandle(), column.getHandle(), false, 0, 0);
+		gtk_tree_view_scroll_to_cell(getHandle(), path.getHandle(), column.getHandle(), false, 0, 0);
 	}
 
 	/**
@@ -343,7 +364,7 @@ public class TreeView extends Container {
 	 * @param column The TreeViewColumn to move horizontally to
 	 */
 	public void scrollToCell(TreeViewColumn column) {
-		gtk_tree_view_scroll_to_cell(handle, 0, column.getHandle(), false, 0, 0);
+		gtk_tree_view_scroll_to_cell(getHandle(), 0, column.getHandle(), false, 0, 0);
 	}
 
 	/**
@@ -352,7 +373,7 @@ public class TreeView extends Container {
 	 * @param path The path of the row to move to, or NULL.
 	 */
 	public void scrollToCell(TreePath path) {
-		gtk_tree_view_scroll_to_cell(handle, path.getHandle(), 0, false, 0, 0);
+		gtk_tree_view_scroll_to_cell(getHandle(), path.getHandle(), 0, false, 0, 0);
 	}
 
 	/**
@@ -368,7 +389,7 @@ public class TreeView extends Container {
 	 * @param startEditing TRUE if the specified cell should start being edited.
 	 */
 	public void setCursor(TreePath path, TreeViewColumn focusColumn, boolean startEditing) {
-		gtk_tree_view_set_cursor(handle, path.getHandle(), focusColumn.getHandle(), startEditing);
+		gtk_tree_view_set_cursor(getHandle(), path.getHandle(), focusColumn.getHandle(), startEditing);
 	}
 
 	/**
@@ -377,7 +398,7 @@ public class TreeView extends Container {
 	public TreePath getCursorPath() {
 		int[] path = new int[1];
 		int[] column = new int[1];
-		gtk_tree_view_get_cursor(handle, path, column);
+		gtk_tree_view_get_cursor(getHandle(), path, column);
 		return new TreePath(path[0]);
 	}
 
@@ -387,7 +408,10 @@ public class TreeView extends Container {
 	public TreeViewColumn getCursorColumn() {
 		int[] path = new int[1];
 		int[] column = new int[1];
-		gtk_tree_view_get_cursor(handle, path, column);
+		gtk_tree_view_get_cursor(getHandle(), path, column);
+		GObject obj = retrieveGObject(column[0]);
+		if (null != obj)
+			return (TreeViewColumn)obj;
 		return new TreeViewColumn(column[0]);
 	}
 
@@ -397,21 +421,21 @@ public class TreeView extends Container {
 	 * @param column The TreeViewColumn to be activated.
 	 */
 	public void activateCell(TreePath path, TreeViewColumn column) {
-		gtk_tree_view_row_activated(handle, path.getHandle(), column.getHandle());
+		gtk_tree_view_row_activated(getHandle(), path.getHandle(), column.getHandle());
 	}
 
 	/**
 	 * Recursively expands all nodes
 	 */
 	public void expandAll() {
-		gtk_tree_view_expand_all(handle);
+		gtk_tree_view_expand_all(getHandle());
 	}
 
 	/**
 	 * Recursively collapses all visible, expanded nodes.
 	 */
 	public void collapseAll() {
-		gtk_tree_view_collapse_all(handle);
+		gtk_tree_view_collapse_all(getHandle());
 	}
 
 	/**
@@ -422,7 +446,7 @@ public class TreeView extends Container {
 	 * @return TRUE if the row existed and had children
 	 */
 	public boolean expandRow(TreePath path, boolean openAll) {
-		return gtk_tree_view_expand_row(handle, path.getHandle(), openAll);
+		return gtk_tree_view_expand_row(getHandle(), path.getHandle(), openAll);
 	}
 
 	/**
@@ -431,7 +455,7 @@ public class TreeView extends Container {
 	 * @return TRUE if the row was collapsed.
 	 */
 	public boolean collapseRow(TreePath path) {
-		return gtk_tree_view_collapse_row(handle, path.getHandle());
+		return gtk_tree_view_collapse_row(getHandle(), path.getHandle());
 	}
 
 	/**
@@ -444,7 +468,7 @@ public class TreeView extends Container {
 	 * @return TRUE if path is expanded.
 	 */
 	public boolean getRowExpanded(TreePath path) {
-		return gtk_tree_view_row_expanded(handle, path.getHandle());
+		return gtk_tree_view_row_expanded(getHandle(), path.getHandle());
 	}
 
 	/**
@@ -461,11 +485,11 @@ public class TreeView extends Container {
 	 * @param reorderable TRUE, if the tree can be reordered.
 	 */
 	public void setReorderable(boolean reorderable) {
-		gtk_tree_view_set_reorderable(handle, reorderable);
+		gtk_tree_view_set_reorderable(getHandle(), reorderable);
 	}
 	
 	public boolean getReorderable() {
-		return gtk_tree_view_get_reorderable(handle);
+		return gtk_tree_view_get_reorderable(getHandle());
 	}
 	
 	/**
@@ -477,14 +501,14 @@ public class TreeView extends Container {
 	 * @param model the new model for the {@link TreeView}
 	 */
 	public void setModel(TreeModel model) {
-			gtk_tree_view_set_model(handle, model.getHandle());
+			gtk_tree_view_set_model(getHandle(), model.getHandle());
 	}
 
 	/**
 	 * Resizes all columns to their optimal width. Only works after the treeview has been realized.
 	 */
 	public void autoSizeColumns(){
-		gtk_tree_view_columns_autosize( handle );
+		gtk_tree_view_columns_autosize( getHandle() );
 	}
 	  
 	 
@@ -492,12 +516,16 @@ public class TreeView extends Container {
 	 * Returns an array of all the columns currently in the view
 	 */
 	public TreeViewColumn[] getColumns(){
-		int[] hndls = gtk_tree_view_get_columns(handle);
+		int[] hndls = gtk_tree_view_get_columns(getHandle());
 		if (null == hndls)
 			return null;
 		TreeViewColumn[] columns = new TreeViewColumn[hndls.length];
 		for (int i = 0; i < hndls.length; i++) {
-			columns[i] = new TreeViewColumn(hndls[i]);
+			GObject obj = retrieveGObject(hndls[i]);
+			if (null != obj)
+				columns[i] = (TreeViewColumn)obj;
+			else
+				columns[i] = new TreeViewColumn(hndls[i]);
 		}
 		return columns;
 	}
@@ -520,7 +548,7 @@ public class TreeView extends Container {
 	 * @param startEditing TRUE if the specified cell should start being edited.
 	 */
 	public void setCursor(TreePath path, TreeViewColumn focusColumn, CellRenderer focusCell, boolean startEditing) {
-		gtk_tree_view_set_cursor_on_cell(handle, path.getHandle(), focusColumn.getHandle(), focusCell.getHandle(), startEditing);
+		gtk_tree_view_set_cursor_on_cell(getHandle(), path.getHandle(), focusColumn.getHandle(), focusCell.getHandle(), startEditing);
 	}
 
 	/**
@@ -531,7 +559,7 @@ public class TreeView extends Container {
 	 * @param path path to a row
 	 */
 	public void expandToPath( TreePath path ){
-		gtk_tree_view_expand_to_path(handle, path.getHandle());
+		gtk_tree_view_expand_to_path(getHandle(), path.getHandle());
 	}
 
 	/**
@@ -552,11 +580,11 @@ public class TreeView extends Container {
 	 * @param enableSearch TRUE, if the user can search interactively
 	 */
 	public void setEnableSearch(boolean enableSearch) {
-		gtk_tree_view_set_enable_search(handle, enableSearch);
+		gtk_tree_view_set_enable_search(getHandle(), enableSearch);
 	}
 	
 	public boolean getEnableSearch() {
-		return gtk_tree_view_get_enable_search(handle);
+		return gtk_tree_view_get_enable_search(getHandle());
 	}
 
 	/**
@@ -565,11 +593,15 @@ public class TreeView extends Container {
 	 * @param column The column to search in
 	 */
 	public void setSearchColumn(TreeViewColumn column) {
-		gtk_tree_view_set_search_column(handle, column.getHandle());
+		gtk_tree_view_set_search_column(getHandle(), column.getHandle());
 	}
 	
 	public TreeViewColumn getSearchColumn() {
-		return new TreeViewColumn(gtk_tree_view_get_search_column(handle));
+		int hndl = gtk_tree_view_get_search_column(getHandle());
+		GObject obj = retrieveGObject(hndl);
+		if (null != obj)
+			return (TreeViewColumn)obj;
+		return new TreeViewColumn(hndl);
 	}
 
 	/**
@@ -645,7 +677,11 @@ public class TreeView extends Container {
 	private void handleRowActivated(int path, int column) {
 		TreeViewEvent event = new TreeViewEvent(this, TreeViewEvent.Type.ROW_ACTIVATED);
 		event.setTreePath(new TreePath(path));
-		event.setTreeColumn(new TreeViewColumn(column));
+		GObject obj = retrieveGObject(column);
+		if (null != obj)
+			event.setTreeColumn((TreeViewColumn)obj);
+		else
+			event.setTreeColumn(new TreeViewColumn(column));
 		fireTreeViewEvent(event);
 	}
 
@@ -714,9 +750,15 @@ public class TreeView extends Container {
 		return true;
 	}
 
+	/** Are events initialized? */
+	private boolean eventsInitialized = false;
+
 	protected void initializeEventHandlers() {
-		super.initializeEventHandlers();
-		evtMap.initialize(this);
+		if (!eventsInitialized) {
+			super.initializeEventHandlers();
+			evtMap.initialize(this);
+			eventsInitialized = true;
+		}
 	}
 
 	public Class getEventListenerClass(String signal) {
