@@ -38,28 +38,6 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1ge
 	return (jint)gtk_file_chooser_get_action((GtkFileChooser*)chooser);
 }
 
-/*
- * Class:     org_gnu_gtk_FileChooserHelper
- * Method:    gtk_file_chooser_set_folder_mode
- * Signature: (IZ)V
- */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1folder_1mode
-  (JNIEnv *env, jclass cls, jint chooser, jboolean folderMode)
-{
-	gtk_file_chooser_set_folder_mode((GtkFileChooser*)chooser, (gboolean)folderMode);
-}
-
-/*
- * Class:     org_gnu_gtk_FileChooserHelper
- * Method:    gtk_file_chooser_get_folder_mode
- * Signature: (I)Z
- */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1get_1folder_1mode
-  (JNIEnv *env, jclass cls, jint chooser)
-{
-	return (jboolean)gtk_file_chooser_get_folder_mode((GtkFileChooser*)chooser);
-}
-
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_set_local_only
@@ -131,27 +109,29 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_set_filename
- * Signature: (ILjava/lang/String;)V
+ * Signature: (ILjava/lang/String;)Z
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1filename
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1filename
   (JNIEnv *env, jclass cls, jint chooser, jstring name)
 {
 	const gchar* n = (*env)->GetStringUTFChars(env, name, NULL);
-	gtk_file_chooser_set_filename((GtkFileChooser*)chooser, n);
+	jboolean value = gtk_file_chooser_set_filename((GtkFileChooser*)chooser, n);
 	(*env)->ReleaseStringUTFChars(env, name, n);
+	return value;
 }
 
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_select_filename
- * Signature: (ILjava/lang/String;)V
+ * Signature: (ILjava/lang/String;)Z
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1select_1filename
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1select_1filename
   (JNIEnv *env, jclass cls, jint chooser, jstring name)
 {
 	const gchar* n = (*env)->GetStringUTFChars(env, name, NULL);
-	gtk_file_chooser_select_filename((GtkFileChooser*)chooser, n);
+	jboolean value = gtk_file_chooser_select_filename((GtkFileChooser*)chooser, n);
 	(*env)->ReleaseStringUTFChars(env, name, n);
+	return value;
 }
 
 /*
@@ -224,14 +204,15 @@ JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1cho
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_set_current_folder
- * Signature: (ILjava/lang/String;)V
+ * Signature: (ILjava/lang/String;)Z
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1current_1folder
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1current_1folder
   (JNIEnv *env, jclass cls, jint chooser, jstring name)
 {
 	const gchar* n = (*env)->GetStringUTFChars(env, name, NULL);
-	gtk_file_chooser_set_current_folder((GtkFileChooser*)chooser, n);
+	jboolean value = gtk_file_chooser_set_current_folder((GtkFileChooser*)chooser, n);
 	(*env)->ReleaseStringUTFChars(env, name, n);
+	return value;
 }
 
 /*
@@ -259,27 +240,29 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_set_uri
- * Signature: (ILjava/lang/String;)V
+ * Signature: (ILjava/lang/String;)Z
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1uri
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1uri
   (JNIEnv *env, jclass cls, jint chooser, jstring name)
 {
 	const gchar* n = (*env)->GetStringUTFChars(env, name, NULL);
-	gtk_file_chooser_set_uri((GtkFileChooser*)chooser, n);
+	jboolean value = gtk_file_chooser_set_uri((GtkFileChooser*)chooser, n);
 	(*env)->ReleaseStringUTFChars(env, name, n);
+	return value;
 }
 
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_select_uri
- * Signature: (ILjava/lang/String;)V
+ * Signature: (ILjava/lang/String;)Z
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1select_1uri
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1select_1uri
   (JNIEnv *env, jclass cls, jint chooser, jstring name)
 {
 	const gchar* n = (*env)->GetStringUTFChars(env, name, NULL);
-	gtk_file_chooser_select_uri((GtkFileChooser*)chooser, n);
+	jboolean value = gtk_file_chooser_select_uri((GtkFileChooser*)chooser, n);
 	(*env)->ReleaseStringUTFChars(env, name, n);
+	return value;
 }
 
 /*
@@ -330,14 +313,15 @@ JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1cho
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_set_current_folder_uri
- * Signature: (ILjava/lang/String;)V
+ * Signature: (ILjava/lang/String;)Z
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1current_1folder_1uri
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1set_1current_1folder_1uri
   (JNIEnv *env, jclass cls, jint chooser, jstring name)
 {
 	const gchar* n = (*env)->GetStringUTFChars(env, name, NULL);
-	gtk_file_chooser_set_current_folder_uri((GtkFileChooser*)chooser, n);
+	jboolean value = gtk_file_chooser_set_current_folder_uri((GtkFileChooser*)chooser, n);
 	(*env)->ReleaseStringUTFChars(env, name, n);
+	return value;
 }
 
 /*
